@@ -35,14 +35,14 @@
 #include <libproc.h>
 #endif
 
-#include "siril.h"
-#include "proto.h"
-#include "conversion.h"
-#include "callbacks.h"
-#include "registration.h"
-#include "stacking.h"
-#include "undo.h"
-#include "single_image.h"
+#include "core/siril.h"
+#include "core/proto.h"
+#include "io/conversion.h"
+#include "gui/callbacks.h"
+#include "registration/registration.h"
+#include "stacking/stacking.h"
+#include "core/undo.h"
+#include "io/single_image.h"
 
 /* the global variables of the whole project */
 cominfo com;	// the main data struct
@@ -263,7 +263,11 @@ int main(int argc, char *argv[]) {
 		com.wd = NULL;
 	} else
 		cwd_orig = strdup(com.wd);
-	checkinitfile();
+
+	if (checkinitfile()) {
+		siril_log_message("could not load or create settings file in ~/.siril, exiting.\n");
+		exit(1);
+	}
 	
 	/* load the css sheet for general style */
 	homepath = getenv("HOME");
